@@ -1,3 +1,4 @@
+# shadowstep/base.py
 import gc
 import importlib
 import json
@@ -10,10 +11,8 @@ from types import ModuleType
 
 import requests
 import inspect
-# Удаляем логуру
-# from loguru import logger
-# Используем наш логгер
-from shadowstep.utils import get_logger
+import logging
+logger = logging.getLogger(__name__)
 from typing import Union, List, Optional, Set
 
 from appium.options.android import UiAutomator2Options
@@ -28,6 +27,7 @@ from shadowstep.terminal.terminal import Terminal
 from shadowstep.terminal.transport import Transport
 
 
+
 class AppiumDisconnectedError(Exception):
     def __init__(
             self, msg: Optional[str] = None, screen: Optional[str] = None,
@@ -50,8 +50,6 @@ class WebDriverSingleton(WebDriver):
 
     @classmethod
     def _get_session_id(cls, kwargs):
-        # Получаем логгер для текущего класса
-        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         res = requests.get(kwargs['command_executor'] + '/sessions')
         res_json = json.loads(res.text)
@@ -63,8 +61,6 @@ class WebDriverSingleton(WebDriver):
     @classmethod
     def clear_instance(cls):
         """Удаляет текущий экземпляр и очищает ресурсы WebDriverSingleton."""
-        # Получаем логгер для текущего класса
-        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         cls._driver = None
         cls._instance = None  # Убирает ссылку на экземпляр для высвобождения памяти
@@ -79,8 +75,6 @@ class WebDriverSingleton(WebDriver):
             WebDriver
                 The current WebDriver instance.
         """
-        # Получаем логгер для текущего класса
-        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         return cls._driver
 
@@ -88,8 +82,7 @@ class WebDriverSingleton(WebDriver):
 class ShadowstepBase:
 
     def __init__(self):
-        # Используем стандартный логгер
-        self.logger = get_logger(f"{__name__}.{self.__class__.__name__}")
+        self.logger = logger
         self.driver: WebDriver = None
         self.server_ip: str = None
         self.server_port: int = None
@@ -409,6 +402,10 @@ class ShadowstepBase:
                                          direct_connection=self.direct_connection,
                                          extensions=self.extensions,
                                          strict_ssl=self.strict_ssl)
+        self._wait_for_session_id()
+        if not self.is_connected():
+            raise AppiumDisconnectedError(msg=f"Не удалось установить подключение к: {command_executor}")
+        self.logger.info(f"Подключение установлено")
         if ssh_user and ssh_password:
             self.transport = Transport(server=self.server_ip,
                                        port=self.ssh_port,
@@ -433,10 +430,10 @@ class ShadowstepBase:
                 self.driver.quit()
                 self.driver = None
         except InvalidSessionIdException as error:
-            self.logger.debug(f"{inspect.currentframe().f_code.co_name} {error}")
+            self.logger.debug(f"{inspect.currentframe().f_code.co_name} InvalidSessionIdException")
             pass
         except NoSuchDriverException as error:
-            self.logger.debug(f"{inspect.currentframe().f_code.co_name} {error}")
+            self.logger.debug(f"{inspect.currentframe().f_code.co_name} NoSuchDriverException")
             pass
 
     def reconnect(self):
@@ -462,6 +459,74 @@ class ShadowstepBase:
         time.sleep(3)
 
     def is_connected(self) -> bool:
+        """
+        Checks whether the current Appium session is active on the grid or standalone server.
+
+        Returns:
+            bool: True if the session is active, False otherwise.
+        """
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
+
+        step = "Checking session status"
+        self.logger.debug(f"[{step}] started")
+        if self._is_session_active_on_grid():
+            return True
+        elif self._is_session_active_on_standalone():
+            return True
+        return False
+
+    def _is_session_active_on_grid(self) -> bool:
+        """
+        Checks if the current session is active in the Selenium Grid.
+
+        Returns:
+            bool: True if session is active in any slot on the grid, False otherwise.
+        """
+        self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
+
+        try:
+            step = "Fetching Grid /status"
+            self.logger.debug(f"[{step}] started")
+
+            url = f"{self.command_executor}/status"
+            response = requests.get(url, timeout=5, verify=False)
+            response.raise_for_status()
+
+            grid = response.json()
+            nodes = grid.get("value", {}).get("nodes", [])
+            self.logger.info(f"{grid=}")
+            self.logger.info(f"{nodes=}")
+
+            step = "Iterating nodes and slots"
+            self.logger.debug(f"[{step}] started")
+            for node in nodes:
+                for slot in node.get("slots", []):
+                    self.logger.info(f"{node=}")
+                    self.logger.info(f"{slot=}")
+                    session = slot.get("session")
+                    self.logger.info(f"{session=}")
+                    if not session:
+                        continue
+                    session_id = session.get("sessionId")
+                    self.logger.info(f"Found session_id on node: {session_id}")
+                    if session_id == self.driver.session_id:
+                        self.logger.debug("Session found in Grid")
+                        return True
+
+            self.logger.debug("Session not found in any Grid slot")
+            return False
+
+        except Exception as error:
+            self.logger.warning(f"_is_session_active_on_grid failed: {error}")
+            return False
+
+    def _is_session_active_on_standalone(self) -> bool:
+        """
+        Fallback check for standalone Appium server via /sessions endpoint (legacy support).
+
+        Returns:
+            bool: True if session is active on standalone Appium, False otherwise.
+        """
         self.logger.debug(f"{inspect.currentframe().f_code.co_name}")
         try:
             response = requests.get(f"{self.command_executor}/sessions")
@@ -477,3 +542,25 @@ class ShadowstepBase:
         except Exception as error:
             self.logger.error(f"{inspect.currentframe().f_code.co_name} {error}")
             return False
+
+    def _wait_for_session_id(self, timeout: int = 30) -> None:
+        """
+        Waits until WebDriver's session_id is set or times out.
+
+        Args:
+            timeout (int): How many seconds to wait before giving up.
+
+        Raises:
+            RuntimeError: If session_id was not set within timeout.
+        """
+        self.logger.info(f"{inspect.currentframe().f_code.co_name}")
+        start_time = time.time()
+        while time.time() - start_time < timeout:
+            self.logger.info(f"{self.driver=}")
+            self.logger.info(f"{self.driver.session_id=}")
+            if self.driver and self.driver.session_id:
+                return
+            time.sleep(0.5)
+            self.driver = WebDriverSingleton.get_driver()
+        raise RuntimeError("WebDriver session_id was not assigned in time.")
+
